# spoti.py
An async wrapper for the [Spotify API](https://developer.spotify.com/documentation/web-api/) written in Python.

## Support
Support for spoti.py can be found in my [Discord](https://discord.com/invite/w9f6NkQbde) or by opening a discussion/issue on the [GitHub repo](https://github.com/Axelancerr/spoti.py)

## Installation

spoti.py is not available on PyPi yet, but it can be installed from GitHub instead:
```shell
pip install -U git+https://github.com/Axelancerr/spoti.py
```

To add spoti.py to a `requirements.txt` file, you can simply add it as: 
```text
git+https://github.com/Axelancerr/spoti.py
```
